[java-identity-provider COMMIT] /trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuth...

noreply at shibboleth.net noreply at shibboleth.net
Tue Jul 16 13:34:46 EDT 2013


Author: scantor
Date: Tue Jul 16 13:34:46 2013
New Revision: 4582

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=4582&view=rev
Log:
Missed a fix.

Modified:
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuthenticationStatementToAssertion.java

Modified: trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuthenticationStatementToAssertion.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuthenticationStatementToAssertion.java?rev=4582&r1=4581&r2=4582&view=diff
==============================================================================
--- trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuthenticationStatementToAssertion.java (original)
+++ trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuthenticationStatementToAssertion.java Tue Jul 16 13:34:46 2013
@@ -21,7 +21,7 @@
 
 import net.shibboleth.ext.spring.webflow.Event;
 import net.shibboleth.ext.spring.webflow.Events;
-import net.shibboleth.idp.authn.AuthenticationRequestContext;
+import net.shibboleth.idp.authn.context.AuthenticationContext;
 import net.shibboleth.idp.profile.AbstractProfileAction;
 import net.shibboleth.idp.profile.ActionSupport;
 import org.opensaml.profile.ProfileException;
@@ -197,12 +197,12 @@
      * 
      * @param profileRequestContext current request context
      * 
      * @return the authentication statement or null if no {@link AuthenticationRequestContext} is available
      */
     private AuthenticationStatement buildAuthenticationStatement(
             final ProfileRequestContext<Object, Response> profileRequestContext) {
-        final AuthenticationRequestContext authnCtx =
-                profileRequestContext.getSubcontext(AuthenticationRequestContext.class, false);
+        final AuthenticationContext authnCtx =
+                profileRequestContext.getSubcontext(AuthenticationContext.class, false);
         if (authnCtx == null) {
             log.debug("Action {}: Not AuthenticationRequestContext available, nothing left to do", getId());
             return null;
@@ -214,7 +214,7 @@
 
         final AuthenticationStatement statement = statementBuilder.buildObject();
         statement.setAuthenticationInstant(new DateTime(authnCtx.getCompletionInstant()));
-        statement.setAuthenticationMethod(authnCtx.getAttemptedWorkflow().get().getWorkflowId());
+        statement.setAuthenticationMethod(authnCtx.getAttemptedWorkflow().getId());
         return statement;
     }
 }
@@ -197,12 +197,12 @@
      * @param profileRequestContext current request context
      * 
-     * @return the authentication statement or null if no {@link AuthenticationRequestContext} is available
+     * @return the authentication statement or null if no {@link AuthenticationContext} is available
      */
     private AuthenticationStatement buildAuthenticationStatement(



More information about the commits mailing list